# Copyright (C) 2009, 2010, 2013, 2014 Nicira Networks, Inc.
#
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without warranty of any kind.
#
# If tests have to be skipped while building, specify the '--without check'
# option. For example:
# rpmbuild -bb --without check rhel/openvswitch-fedora.spec

# This defines the base package name's version.

%define pkgver 2.13
%define pkgname ovn24.03

# If libcap-ng isn't available and there is no need for running OVS
# as regular user, specify the '--without libcapng'
%bcond_without libcapng

# Enable PIE, bz#955181
%global _hardened_build 1

# RHEL-7 doesn't define _rundir macro yet
# Fedora 15 onwards uses /run as _rundir
%if 0%{!?_rundir:1}
%define _rundir /run
%endif

# Build python2 (that provides python) and python3 subpackages on Fedora
# Build only python3 (that provides python) subpackage on RHEL8
# Build only python subpackage on RHEL7
%if 0%{?rhel} > 7 || 0%{?fedora}
# On RHEL8 Sphinx is included in buildroot
%global external_sphinx 1
%else
# Don't use external sphinx (RHV doesn't have optional repositories enabled)
%global external_sphinx 0
%endif

# We would see rpmlinit error - E: hardcoded-library-path in '% {_prefix}/lib'.
# But there is no solution to fix this. Using {_lib} macro will solve the
# rpmlink error, but will install the files in /usr/lib64/.
# OVN pacemaker ocf script file is copied in /usr/lib/ocf/resource.d/ovn/
# and we are not sure if pacemaker looks into this path to find the
# OVN resource agent script.
%global ovnlibdir %{_prefix}/lib

Name: %{pkgname}
Summary: Open Virtual Network support
Group: System Environment/Daemons
URL: http://www.ovn.org/
Version: 24.03.4
Release: 53%{?commit0:.%{date}git%{shortcommit0}}%{?dist}
Provides: openvswitch%{pkgver}-ovn-common = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-common < 2.11.0-1

# Nearly all of openvswitch is ASL 2.0.  The bugtool is LGPLv2+, and the
# lib/sflow*.[ch] files are SISSL
License: ASL 2.0 and LGPLv2+ and SISSL

%define ovncommit af5e1ee49c6f7179c2bedd8a5fc49048b7041f33

# Always pull an upstream release, since this is what we rebase to.
Source: https://github.com/ovn-org/ovn/archive/%{ovncommit}.tar.gz#/ovn-%{version}.tar.gz

%define ovscommit dfe601bbc154c836e6ec3526a1eb331c1c09a06e
%define ovsshortcommit dfe601b

Source10: https://github.com/openvswitch/ovs/archive/%{ovscommit}.tar.gz#/openvswitch-%{ovsshortcommit}.tar.gz
%define ovsdir ovs-%{ovscommit}

%define docutilsver 0.12
%define pygmentsver 1.4
%define sphinxver   1.1.3
Source100: https://pypi.io/packages/source/d/docutils/docutils-%{docutilsver}.tar.gz
Source101: https://pypi.io/packages/source/P/Pygments/Pygments-%{pygmentsver}.tar.gz
Source102: https://pypi.io/packages/source/S/Sphinx/Sphinx-%{sphinxver}.tar.gz

Source500: configlib.sh
Source501: gen_config_group.sh
Source502: set_config.sh

# Important: source503 is used as the actual copy file
# @TODO: this causes a warning - fix it?
Source504: arm64-armv8a-linuxapp-gcc-config
Source505: ppc_64-power8-linuxapp-gcc-config
Source506: x86_64-native-linuxapp-gcc-config

Patch:     %{pkgname}.patch

# FIXME Sphinx is used to generate some manpages, unfortunately, on RHEL, it's
# in the -optional repository and so we can't require it directly since RHV
# doesn't have the -optional repository enabled and so TPS fails
%if %{external_sphinx}
BuildRequires: python3-sphinx
%else
# Sphinx dependencies
BuildRequires: python-devel
BuildRequires: python-setuptools
#BuildRequires: python2-docutils
BuildRequires: python-jinja2
BuildRequires: python-nose
#BuildRequires: python2-pygments
# docutils dependencies
BuildRequires: python-imaging
# pygments dependencies
BuildRequires: python-nose
%endif

BuildRequires: gcc gcc-c++ make
BuildRequires: autoconf automake libtool
BuildRequires: systemd-units openssl openssl-devel
BuildRequires: python3-devel python3-setuptools
BuildRequires: desktop-file-utils
BuildRequires: groff-base graphviz
BuildRequires: unbound-devel

# make check dependencies
BuildRequires: procps-ng
%if 0%{?rhel} == 8 || 0%{?fedora}
BuildRequires: python3-pyOpenSSL
%endif
BuildRequires: tcpdump

%if %{with libcapng}
BuildRequires: libcap-ng libcap-ng-devel
%endif

%if 0%{?rhel} >= 9
BuildRequires: python3-scapy
%endif

Requires: hostname openssl iproute module-init-tools

Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

# to skip running checks, pass --without check
%bcond_without check

%description
OVN, the Open Virtual Network, is a system to support virtual network
abstraction.  OVN complements the existing capabilities of OVS to add
native support for virtual network abstractions, such as virtual L2 and L3
overlays and security groups.

%package central
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Requires: firewalld-filesystem
Provides: openvswitch%{pkgver}-ovn-central = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-central < 2.11.0-1

%description central
OVN DB servers and ovn-northd running on a central node.

%package host
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Requires: firewalld-filesystem
Provides: openvswitch%{pkgver}-ovn-host = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-host < 2.11.0-1

%description host
OVN controller running on each host.

%package vtep
Summary: Open Virtual Network support
License: ASL 2.0
Requires: %{pkgname}
Provides: openvswitch%{pkgver}-ovn-vtep = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: openvswitch%{pkgver}-ovn-vtep < 2.11.0-1

%description vtep
OVN vtep controller

%prep
%autosetup -n ovn-%{ovncommit} -a 10 -p 1

%build
%if 0%{?commit0:1}
# fix the snapshot unreleased version to be the released one.
sed -i.old -e "s/^AC_INIT(openvswitch,.*,/AC_INIT(openvswitch, %{version},/" configure.ac
%endif
./boot.sh

# OVN source code is now separate.
# Build openvswitch first.
# XXX Current openvswitch2.13 doesn't
# use "2.13.0" for version. It's a commit hash
pushd %{ovsdir}
./boot.sh
%configure \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --enable-ssl \
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki

make %{?_smp_mflags}
popd

# Build OVN.
# XXX OVS version needs to be updated when ovs2.13 is updated.
%configure \
        --with-ovs-source=$PWD/%{ovsdir} \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --enable-ssl \
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki

make %{?_smp_mflags}

%install
%make_install
install -p -D -m 0644 \
        rhel/usr_share_ovn_scripts_systemd_sysconfig.template \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/ovn

for service in ovn-controller ovn-controller-vtep ovn-northd; do
        install -p -D -m 0644 \
                        rhel/usr_lib_systemd_system_${service}.service \
                        $RPM_BUILD_ROOT%{_unitdir}/${service}.service
done

install -d -m 0755 $RPM_BUILD_ROOT/%{_sharedstatedir}/ovn

install -d $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/
install -p -m 0644 rhel/usr_lib_firewalld_services_ovn-central-firewall-service.xml \
        $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/ovn-central-firewall-service.xml
install -p -m 0644 rhel/usr_lib_firewalld_services_ovn-host-firewall-service.xml \
        $RPM_BUILD_ROOT%{ovnlibdir}/firewalld/services/ovn-host-firewall-service.xml

install -d -m 0755 $RPM_BUILD_ROOT%{ovnlibdir}/ocf/resource.d/ovn
ln -s %{_datadir}/ovn/scripts/ovndb-servers.ocf \
      $RPM_BUILD_ROOT%{ovnlibdir}/ocf/resource.d/ovn/ovndb-servers

install -p -D -m 0644 rhel/etc_logrotate.d_ovn \
        $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d/ovn

# remove unneeded files.
rm -f $RPM_BUILD_ROOT%{_bindir}/ovs*
rm -f $RPM_BUILD_ROOT%{_bindir}/vtep-ctl
rm -f $RPM_BUILD_ROOT%{_sbindir}/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man5/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man5/vtep*
rm -f $RPM_BUILD_ROOT%{_mandir}/man7/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/ovs*
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/vtep*
rm -rf $RPM_BUILD_ROOT%{_datadir}/ovn/python
rm -f $RPM_BUILD_ROOT%{_datadir}/ovn/scripts/ovs*
rm -rf $RPM_BUILD_ROOT%{_datadir}/ovn/bugtool-plugins
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/pkgconfig/*.pc
rm -f $RPM_BUILD_ROOT%{_includedir}/ovn/*
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/ovs-appctl-bashcomp.bash
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/ovs-vsctl-bashcomp.bash
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/openvswitch
rm -f $RPM_BUILD_ROOT%{_datadir}/ovn/scripts/ovn-bugtool*
rm -f $RPM_BUILD_ROOT/%{_bindir}/ovn-docker-overlay-driver \
        $RPM_BUILD_ROOT/%{_bindir}/ovn-docker-underlay-driver

%check
%if %{with check}
    touch resolv.conf
    export OVS_RESOLV_CONF=$(pwd)/resolv.conf
    if ! make check TESTSUITEFLAGS='%{_smp_mflags}'; then
        cat tests/testsuite.log
        if ! make check TESTSUITEFLAGS='--recheck'; then
            cat tests/testsuite.log
            # Presently a test case - "2796: ovn -- ovn-controller incremental processing"
            # is failing on aarch64 arch. Let's not exit for this arch
            # until we figure out why it is failing.
            # Test case 93: ovn.at:12105       ovn -- ACLs on Port Groups is failing
            # repeatedly on s390x. This needs to be investigated.
            %ifnarch aarch64
            %ifnarch ppc64le
            %ifnarch s390x
                exit 1
            %endif
            %endif
            %endif
        fi
    fi
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%pre central
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-northd.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-central > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-northd service is running which means old openvswitch-ovn-central
        # is already installed and it will be cleaned up. So start ovn-northd
        # service when posttrans central is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-northd
    fi
fi

%pre host
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-controller.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-host > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-controller service is running which means old
        # openvswitch-ovn-host is installed and it will be cleaned up. So
        # start ovn-controller service when posttrans host is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-controller
    fi
fi

%pre vtep
if [ $1 -eq 1 ] ; then
    # Package install.
    /bin/systemctl status ovn-controller-vtep.service >/dev/null
    ovn_status=$?
    rpm -ql openvswitch-ovn-vtep > /dev/null
    if [[ "$?" = "0" && "$ovn_status" = "0" ]]; then
        # ovn-controller-vtep service is running which means old
        # openvswitch-ovn-vtep is installed and it will be cleaned up. So
        # start ovn-controller-vtep service when posttrans host is called.
        touch %{_localstatedir}/lib/rpm-state/ovn-controller-vtep
    fi
fi

%preun central
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-northd.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-northd.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-northd.service >/dev/null 2>&1 || :
    fi
%endif

%preun host
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-controller.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-controller.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-controller.service >/dev/null 2>&1 || :
    fi
%endif

%preun vtep
%if 0%{?systemd_preun:1}
    %systemd_preun ovn-controller-vtep.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable ovn-controller-vtep.service >/dev/null 2>&1 || :
        /bin/systemctl stop ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
%endif

%post
%if %{with libcapng}
if [ $1 -eq 1 ]; then
    sed -i 's:^#OVN_USER_ID=:OVN_USER_ID=:' %{_sysconfdir}/sysconfig/ovn
    sed -i 's:\(.*su\).*:\1 openvswitch openvswitch:' %{_sysconfdir}/logrotate.d/ovn
fi
%endif

%post central
%if 0%{?systemd_post:1}
    %systemd_post ovn-northd.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%post host
%if 0%{?systemd_post:1}
    %systemd_post ovn-controller.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%post vtep
%if 0%{?systemd_post:1}
    %systemd_post ovn-controller-vtep.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%postun

%postun central
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-northd.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
    # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-northd.service >/dev/null 2>&1 || :
    fi
%endif

%postun host
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-controller.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
        # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-controller.service >/dev/null 2>&1 || :
    fi
%endif

%postun vtep
%if 0%{?systemd_postun_with_restart:1}
    %systemd_postun_with_restart ovn-controller-vtep.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ "$1" -ge "1" ] ; then
        # Package upgrade, not uninstall
        /bin/systemctl try-restart ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
%endif

%posttrans central
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-northd ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-northd
        /bin/systemctl start ovn-northd.service >/dev/null 2>&1 || :
    fi
fi


%posttrans host
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-controller ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-controller
        /bin/systemctl start ovn-controller.service >/dev/null 2>&1 || :
    fi
fi

%posttrans vtep
if [ $1 -eq 1 ]; then
    # Package install, not upgrade
    if [ -e %{_localstatedir}/lib/rpm-state/ovn-controller-vtep ]; then
        rm %{_localstatedir}/lib/rpm-state/ovn-controller-vtep
        /bin/systemctl start ovn-controller-vtep.service >/dev/null 2>&1 || :
    fi
fi

%files
%{_bindir}/ovn-nbctl
%{_bindir}/ovn-sbctl
%{_bindir}/ovn-trace
%{_bindir}/ovn-detrace
%{_bindir}/ovn_detrace.py
%{_bindir}/ovn-appctl
%{_bindir}/ovn-ic-nbctl
%{_bindir}/ovn-ic-sbctl
%{_bindir}/ovn-debug
%dir %{_datadir}/ovn/
%dir %{_datadir}/ovn/scripts/
%{_datadir}/ovn/scripts/ovn-ctl
%{_datadir}/ovn/scripts/ovn-lib
%{_datadir}/ovn/scripts/ovndb-servers.ocf
%{_mandir}/man8/ovn-ctl.8*
%{_mandir}/man8/ovn-appctl.8*
%{_mandir}/man8/ovn-nbctl.8*
%{_mandir}/man8/ovn-ic-nbctl.8*
%{_mandir}/man8/ovn-trace.8*
%{_mandir}/man1/ovn-detrace.1*
%{_mandir}/man7/ovn-architecture.7*
%{_mandir}/man8/ovn-sbctl.8*
%{_mandir}/man8/ovn-ic-sbctl.8*
%{_mandir}/man8/ovn-debug.8*
%{_mandir}/man5/ovn-nb.5*
%{_mandir}/man5/ovn-ic-nb.5*
%{_mandir}/man5/ovn-sb.5*
%{_mandir}/man5/ovn-ic-sb.5*
%dir %{ovnlibdir}/ocf/resource.d/ovn/
%{ovnlibdir}/ocf/resource.d/ovn/ovndb-servers
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/logrotate.d/ovn
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/sysconfig/ovn

%files central
%{_bindir}/ovn-northd
%{_bindir}/ovn-ic
%{_mandir}/man8/ovn-northd.8*
%{_mandir}/man8/ovn-ic.8*
%{_datadir}/ovn/ovn-nb.ovsschema
%{_datadir}/ovn/ovn-ic-nb.ovsschema
%{_datadir}/ovn/ovn-sb.ovsschema
%{_datadir}/ovn/ovn-ic-sb.ovsschema
%{_unitdir}/ovn-northd.service
%{ovnlibdir}/firewalld/services/ovn-central-firewall-service.xml

%files host
%{_bindir}/ovn-controller
%{_mandir}/man8/ovn-controller.8*
%{_unitdir}/ovn-controller.service
%{ovnlibdir}/firewalld/services/ovn-host-firewall-service.xml

%files vtep
%{_bindir}/ovn-controller-vtep
%{_mandir}/man8/ovn-controller-vtep.8*
%{_unitdir}/ovn-controller-vtep.service

%changelog
* Tue Jan 21 2025 Mark Michelson <mmichels@redhat.com> - 24.03.4-53
- Prepare for 24.03.6.
[Upstream: 7dd5d8f82030e4927fca24d99d2b46816b6de4dc]

* Tue Jan 21 2025 Mark Michelson <mmichels@redhat.com> - 24.03.4-52
- Set release date for 24.03.5.
[Upstream: f5a4704f9be07f7c29e45bb15e7e71126c6fea4a]

* Tue Jan 21 2025 Numan Siddique <numans@ovn.org> - 24.03.4-51
- Skip only OVN DNS responder packets from OUT_ACL.
[Upstream: 70618a65fd49f1d1d5498927c0bed63e296dafb7]

* Mon Jan 20 2025 MJ Ponsonby <mj.ponsonby@canonical.com> - 24.03.4-50
- Allow LR to send RAs through localnet port.
[Upstream: 2ee49f7a27ed4b9a5785e97d6f9d5ea4dfa41fd8]

* Fri Jan 17 2025 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 24.03.4-49
- controller: Update physical flows for peer port when the patch port is removed. (#FDP-947)
[Upstream: 400044489ab35aef4a02ec336ef894c518615ac9]

* Fri Jan 17 2025 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 24.03.4-48
- northd: Trigger a full recompute if add-route option is toggled. (#FDP-1045)
[Upstream: 70f09a0e6d4a14b3aecb4b8f4bf46fcebb21f89a]

* Fri Jan 17 2025 Frode Nordahl <fnordahl@ubuntu.com> - 24.03.4-47
- tests: Use IPv6 prefix reserved for documentation.
[Upstream: dd802680b2c15b2e1b541d45d177d2c643bb43ed]

* Fri Jan 17 2025 Frode Nordahl <fnordahl@ubuntu.com> - 24.03.4-46
- tests: Explicitly store hex IPv6 PD prefix.
[Upstream: 607009b880e5183ad44702026b74453b3511c8a4]

* Fri Jan 17 2025 Frode Nordahl <fnordahl@ubuntu.com> - 24.03.4-45
- tests: Use /64s for IPv6 Prefix Delegation test.
[Upstream: 1138b822d438b859996c2eadaeb196dd43acc278]

* Fri Jan 17 2025 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 24.03.4-44
- controller: binding: Set HTB root max-rate according to the link speed.
[Upstream: 368b1aac561880d736b2ca1293c003788626b0fd]

* Fri Jan 17 2025 Xavier Simonart <xsimonar@redhat.com> - 24.03.4-43
- tests: Add missing check for ovn-nbctl.
[Upstream: b842aa2cb057c9174e7a1d8105d1a4865f5504b9]

* Fri Jan 17 2025 Xavier Simonart <xsimonar@redhat.com> - 24.03.4-42
- tests: Add check_uuid in tests.
[Upstream: 657d6df058da2f66950b0bf2cfe1a0ad2f4c32d1]

* Fri Jan 17 2025 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 24.03.4-41
- test: ovn-northd: Use check for ovn-nbctl wherever possible. (#FDP-875)
[Upstream: e3dd3ee4dc1161981dfeb333a3a9d12ec1fe75cf]

* Fri Jan 17 2025 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 24.03.4-40
- test: Use check for ovn-sbctl wherever possible. (#FDP-875)
[Upstream: 5c67017ba448ee22a55fbf2ad8d854d9ddc8ffa3]

* Fri Jan 17 2025 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 24.03.4-39
- test: system-ovn: Use check for ovn-nbctl wherever possible. (#FDP-875)
[Upstream: b201c431d6304663803c7eec80c081f5da8b2d86]

* Fri Jan 17 2025 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 24.03.4-38
- test: ovn: Use check for ovn-nbctl wherever possible. (#FDP-875)
[Upstream: 8374312f1ee4dd59e92f7ab157c730791eb8148f]

* Fri Jan 17 2025 Ales Musil <amusil@redhat.com> - 24.03.4-37
- northd: Don't SNAT reply packets on LBs with lb_force_snat_ip set. (#FDP-1009)
[Upstream: e7f754c4b7be82562528b3ac828a1456e3f25580]

* Thu Jan 16 2025 Ales Musil <amusil@redhat.com> - 24.03.4-36
- system-tests: Add check for LB related in reply direction.
[Upstream: f35818a5e71647a19af7f9a94e40ad5b5afe32aa]

* Thu Jan 16 2025 Xavier Simonart <xsimonar@redhat.com> - 24.03.4-35
- tests: Fix flaky "ovn-controller incremental processing".
[Upstream: 8e831cc7de8aa04bcb982ed5164caa9d58119d93]

* Thu Jan 16 2025 Xavier Simonart <xsimonar@redhat.com> - 24.03.4-34
- tests: Fix flaky "ovs-appctl -t ovsdb-server ...".
[Upstream: 5d0ebb455711edd59def6a5eb820dfa2080067a9]

* Thu Jan 16 2025 Xavier Simonart <xsimonar@redhat.com> - 24.03.4-33
- tests: Fix flaky "ovn-sbctl - ovn-sbctl - count-flows - daemon".
[Upstream: 658a44655ae750e82355aee5084fc7109fbe4242]

* Thu Jan 16 2025 Xavier Simonart <xsimonar@redhat.com> - 24.03.4-32
- tests: Fix flaky "OVN FDB (MAC learning)".
[Upstream: 1d814289c99eb0da71bdde90ffa502f2fbf38373]

* Thu Jan 16 2025 Xavier Simonart <xsimonar@redhat.com> - 24.03.4-31
- tests: Fix flaky "ovn-controller-vtep - chassis".
[Upstream: f9903e427455c3989a04f8e38e6b0fcff6ed2b86]

* Thu Jan 16 2025 Xavier Simonart <xsimonar@redhat.com> - 24.03.4-30
- tests: Fix flaky "controller event".
[Upstream: 1f649716e7adcfe8f2d27cc32fd14b745beb2260]

* Thu Jan 16 2025 Xavier Simonart <xsimonar@redhat.com> - 24.03.4-29
- tests: Fix flaky "send gratuitous arp with nat-addresses ...".
[Upstream: 1d3946a111233c96565276a3639ce7ba7ed2a813]

* Thu Jan 16 2025 Xavier Simonart <xsimonar@redhat.com> - 24.03.4-28
- tests: Fix flaky "ofctrl wait before clearing flows".
[Upstream: 49676fe75f97cf8f1a99aaaf5fbc2a19e8f63cf7]

* Thu Jan 16 2025 Xavier Simonart <xsimonar@redhat.com> - 24.03.4-27
- tests: Implement send_garp using scapy.
[Upstream: 04c852a1d7fe3d2d34c1fb7dbb1ff26ea2e3b7b8]

* Mon Dec 23 2024 Vladislav Odintsov <vlodintsov@k2.cloud> - 24.03.4-26
- docs: Fix route lookup behavior description.
[Upstream: 47c92ceccdf1db3c90439a634194040ca048d8d5]

* Mon Dec 23 2024 Ales Musil <amusil@redhat.com> - 24.03.4-25
- controller: Reduce the time it takes to remove multiple ports. (#FDP-1012)
[Upstream: ecffd3387f0aae87fe481881068c38f3889ac574]

* Fri Dec 20 2024 Xavier Simonart <xsimonar@redhat.com> - 24.03.4-24
- controller: Properly handle localnet flows in I+P.
[Upstream: 68241f15570ac8bc8b7252b037e3bde8726cbeab]

* Fri Dec 20 2024 MJ Ponsonby <mj.ponsonby@canonical.com> - 24.03.4-23
- Allow LR to send RAs with only link local Ipv6.
[Upstream: 21e14f6af4f5ec7335141f1a7ad59aa4e911a066]

* Wed Dec 11 2024 Xavier Simonart <xsimonar@redhat.com> - 24.03.4-22
- tests: Fix typos found using check_uuid.
[Upstream: ce1945367ba1ebd3634abb44d4d23a55d63ec7f8]

* Wed Dec 11 2024 Aleksandr Smirnov <AleksSmirnov@k2.cloud> - 24.03.4-21
- northd: Fix issues in RBAC tables recovery.
[Upstream: 4dcb4b0c3be750a75bd8fc4235865c1d73495246]

* Wed Dec 11 2024 Dumitru Ceara <dceara@redhat.com> - 24.03.4-20
- logical-fields: Reuse registers for ct_*_dst() actions.
[Upstream: 17b17dfda01b42913d4c671bbda692fdbf881995]

* Wed Dec 11 2024 Ales Musil <amusil@redhat.com> - 24.03.4-19
- lex: Indicate that the template wasn't found during parsing. (#FDP-607)
[Upstream: 29113e8da452181e8b364c08e98a5c8de5fb88bc]

* Mon Dec 02 2024 Rosemarie O'Riorden <rosemarie@redhat.com> - 24.03.4-18
- controller: Prevent crash when db is empty. (#FDP-715)
[Upstream: b751a1a050a1d8c2ca36699ce81b8e9126c2034a]

* Mon Dec 02 2024 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 24.03.4-17
- test: system-ovn: Fix typos in system-test (#FDP-875)
[Upstream: 78e52c2f2358978cd28899a02cc7e5edad0cd1a1]

* Mon Dec 02 2024 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 24.03.4-16
- test: ovn-northd: Fix typos in unit-test (#FDP-875)
[Upstream: 44fd438348c10186e2be3f09872dfd4778ab9200]

* Mon Dec 02 2024 Lorenzo Bianconi <lorenzo.bianconi@redhat.com> - 24.03.4-15
- test: ovn: Fix typos in unit-test (#FDP-875)
[Upstream: 8477b177b570bd6b5edfbdabadc3695ea680172c]

* Thu Nov 21 2024 Ilya Maximets <i.maximets@ovn.org> - 24.03.4-14
- northd: Don't generate IPv6 prefix delegation flows if not configured. (#FDP-992)
[Upstream: 81ef85707ed7959da629b6481edb0e943693abaa]

* Thu Nov 21 2024 Ilya Maximets <i.maximets@ovn.org> - 24.03.4-13
- northd: Add missing multicast match to DHCPv6 options flows.
[Upstream: 120ba7d8754d697bf129df06e2dbfc4598e3a1fd]

* Tue Nov 12 2024 Aleksandr Smirnov <AleksSmirnov@k2.cloud> - 24.03.4-12
- northd: Populate additional-chassis to HA group.
[Upstream: 1ab5555c351aab44a5e0e6d528ef19dba848138f]

* Fri Nov 08 2024 Numan Siddique <numans@ovn.org> - 24.03.4-11
- Fix load balanced hairpin traffic for fragmented packets. (#FDP-905)
[Upstream: 3a3b28d94b141d4f4900331999323e7b2581f635]

* Wed Nov 06 2024 Xavier Simonart <xsimonar@redhat.com> - 24.03.4-10
- tests: Wait for controller exit before restart.
[Upstream: 570b968c25d76a767416d27b691b8262add424c4]

* Tue Nov 05 2024 Xavier Simonart <xsimonar@redhat.com> - 24.03.4-9
- Revert "controller: Properly handle localnet flows in I+P.". (#FDP-926)
[Upstream: c5d851bb53dc39d6bfcac7df806c64e58c0cd77b]

* Mon Nov 04 2024 Dumitru Ceara <dceara@redhat.com> - 24.03.4-8
- pinctrl: Skip non-local mac bindings in run_buffered_binding().
[Upstream: ed9b0cfff9439fce686ab0393323e588096e52ba]

* Mon Nov 04 2024 Dumitru Ceara <dceara@redhat.com> - 24.03.4-7
- pinctrl: Skip deleted mac bindings in run_buffered_binding().
[Upstream: 0ab05e52649de1dfe2412d3305690081199df8ac]

* Mon Nov 04 2024 Dumitru Ceara <dceara@redhat.com> - 24.03.4-6
- mac-cache: Properly handle deletion of SB mac_bindings. (#FDP-906)
[Upstream: 75737597e0e1281250a0f04bb8eb3a54fcf05292]

* Tue Oct 29 2024 Naveen Yerramneni <naveen.yerramneni@nutanix.com> - 24.03.4-5
- controller: Fix "use after free" issue in statctrl_run().
[Upstream: 6a379bd46b6d23532c3335a7c6cd0676db85c0ba]

* Fri Oct 18 2024 Mark Michelson <mmichels@redhat.com> - 24.03.4-4
- Prepare for 24.03.5.
[Upstream: ca88ccb91aa11fa8e88e41d83d9423ee4e584506]

